@@ -1,17 +1,17 @@
 use strict;
 use warnings;
-package App::Nopaste; # git description: 1.004-20-g46505dd
+package App::Nopaste; # git description: 1.007-3-gab6bb93
 # ABSTRACT: Easy access to any pastebin
 # KEYWORDS: application executable paste output pastebin debugging
 
-our $VERSION = '1.005';
+our $VERSION = '1.008';
 
 use 5.008003;
 use Module::Pluggable search_path => 'App::Nopaste::Service', sub_name => '_plugins';
 use Class::Load 'load_class';
 use namespace::clean 0.19;
 
-use base 'Exporter';
+use parent 'Exporter';
 our @EXPORT_OK = 'nopaste';
 
 sub plugins { goto \&_plugins };
@@ -101,7 +101,7 @@ App::Nopaste - Easy access to any pastebin
 
 =head1 VERSION
 
-version 1.005
+version 1.008
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,7 @@ Shawn M Moore, <sartak@gmail.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet David Golden Dean Hamstead Sergey Romanov Jesse Luehrs Rafael Kitover Сергей Романов Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa gregor herrmann vti Ævar Arnfjörð Bjarmason
+=for stopwords Shawn M Moore Karen Etheridge Thomas Sibley François Gannaz Ricardo Signes Justin Hunter Kevin Falcone Zoffix Znet Sergey Romanov David Golden Jesse Luehrs Dean Hamstead Rafael Kitover Ævar Arnfjörð Bjarmason Сергей Романов Arthur Axel 'fREW' Schmidt יובל קוג'מן (Yuval Kogman) Darian Anthony Patrick Bremner J. Shultz Graham Knop Jason Mills John Goulah Maximilian Gass Sebastian Paaske Tørholm Tatsuhiko Miyagawa Zakariyya Mughal gregor herrmann vti
 
 =over 4
 
@@ -241,26 +241,30 @@ Zoffix Znet <cpan@zoffix.com>
 
 =item *
 
-David Golden <dagolden@cpan.org>
-
-=item *
-
-Dean Hamstead <dean@fragfest.com.au>
-
-=item *
-
 Sergey Romanov <complefor@rambler.ru>
 
 =item *
 
+David Golden <dagolden@cpan.org>
+
+=item *
+
 Jesse Luehrs <doy@tozt.net>
 
 =item *
 
+Dean Hamstead <dean@fragfest.com.au>
+
+=item *
+
 Rafael Kitover <rkitover@cpan.org>
 
 =item *
 
+Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+
+=item *
+
 Сергей Романов <sromanov@cpan.org>
 
 =item *
@@ -309,16 +313,16 @@ Tatsuhiko Miyagawa <miyagawa@bulknews.net>
 
 =item *
 
+Zakariyya Mughal <zaki.mughal@gmail.com>
+
+=item *
+
 gregor herrmann <gregoa@debian.org>
 
 =item *
 
 vti <viacheslav.t@gmail.com>
 
-=item *
-
-Ævar Arnfjörð Bjarmason <avarab@gmail.com>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
