@@ -3,9 +3,11 @@ use warnings;
 package App::Nopaste::Service::Codepeek;
 # ABSTRACT: (DEPRECATED) Service for Codepeek - http://codepeek.com
 
-our $VERSION = '1.005';
+our $VERSION = '1.008';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
+
+warnings::warnif('deprecated', 'codepeek.com is offline, so this service no longer works');
 
 sub uri { 'http://codepeek.com/paste' }
 
@@ -49,7 +51,7 @@ App::Nopaste::Service::Codepeek - (DEPRECATED) Service for Codepeek - http://cod
 
 =head1 VERSION
 
-version 1.005
+version 1.008
 
 =head1 DEPRECATION NOTICE
 
