@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Debian;
-# ABSTRACT: Service provider for Debian - http://paste.debian.net/
+# ABSTRACT: Service provider for Debian - https://paste.debian.net/
 
-our $VERSION = '1.006';
+our $VERSION = '1.008';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 my $languages = {
     "text" => "-1",
@@ -246,7 +246,7 @@ my $languages = {
     "yaml" => "yaml",
 };
 
-sub uri { "http://paste.debian.net/" }
+sub uri { "https://paste.debian.net/" }
 
 sub fill_form {
     my $self = shift;
@@ -286,11 +286,11 @@ __END__
 
 =head1 NAME
 
-App::Nopaste::Service::Debian - Service provider for Debian - http://paste.debian.net/
+App::Nopaste::Service::Debian - Service provider for Debian - https://paste.debian.net/
 
 =head1 VERSION
 
-version 1.006
+version 1.008
 
 =for stopwords Niebur
 
