@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Gist;
 # ABSTRACT: Service provider for GitHub gist - http://gist.github.com/
 
-our $VERSION = '1.006';
+our $VERSION = '1.008';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 use JSON::MaybeXS;
 use Module::Runtime 'use_module';
@@ -30,7 +30,7 @@ sub run {
     };
 
     my $filename = defined $arg{filename}
-                 ? path($arg{filename})->basename->stringify
+                 ? path($arg{filename})->basename
                  : 'nopaste';
 
     $content->{files} = {
@@ -78,6 +78,7 @@ sub _get_auth {
         );
     }
     else {
+        # this is also done by the fallback mechanism in Config::Identity::GitHub.
         my $github_config = path('~', '.github');
         if (-f $github_config) {
             my $content = $github_config->slurp_utf8;
@@ -170,7 +171,7 @@ App::Nopaste::Service::Gist - Service provider for GitHub gist - http://gist.git
 
 =head1 VERSION
 
-version 1.006
+version 1.008
 
 =for stopwords SIGNES gists oauth plaintext
 
@@ -186,9 +187,9 @@ or you can use this module to do the same:
 
     perl -MApp::Nopaste::Service::Gist -e 'App::Nopaste::Service::Gist->create_token'
 
-This will grant gist rights to the L<App::Nopaste>, don't worry you can revoke
+This will grant gist rights to the L<App::Nopaste>. Don't worry, you can revoke
 access rights anytime from the GitHub profile settings. Search for C<token> in
-response and export it as C<GITHUB_OAUTH_TOKEN> environment variable.
+response and export it as the C<GITHUB_OAUTH_TOKEN> environment variable.
 
 Alternatively, you can export the C<GITHUB_USER> and C<GITHUB_PASSWORD>
 environment variables, just like for the
