@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Pastie;
 # ABSTRACT: Service provider for Pastie - pastie.org
 
-our $VERSION = '1.006';
+our $VERSION = '1.008';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 my %languages = (
     "bash" => "13",
@@ -109,7 +109,7 @@ App::Nopaste::Service::Pastie - Service provider for Pastie - pastie.org
 
 =head1 VERSION
 
-version 1.006
+version 1.008
 
 =head1 SUPPORT
 
