@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Shadowcat;
 # ABSTRACT: Service provider for Shadowcat - http://paste.scsys.co.uk/
 
-our $VERSION = '1.005';
+our $VERSION = '1.008';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 sub available {
     my $self = shift;
@@ -29,7 +29,7 @@ App::Nopaste::Service::Shadowcat - Service provider for Shadowcat - http://paste
 
 =head1 VERSION
 
-version 1.005
+version 1.008
 
 =head1 SUPPORT
 
