@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 package App::Nopaste::Service::Ubuntu;
-# ABSTRACT: Service provider for Ubuntu - http://paste.ubuntu.com/
+# ABSTRACT: Service provider for Ubuntu - https://paste.ubuntu.com/
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 use parent 'App::Nopaste::Service';
 
@@ -207,7 +207,7 @@ my $languages = {
     "YAML"                           => "yaml",
 };
 
-sub uri { "http://paste.ubuntu.com/" }
+sub uri { "https://paste.ubuntu.com/" }
 
 sub fill_form {
     my $self = shift;
@@ -244,11 +244,11 @@ __END__
 
 =head1 NAME
 
-App::Nopaste::Service::Ubuntu - Service provider for Ubuntu - http://paste.ubuntu.com/
+App::Nopaste::Service::Ubuntu - Service provider for Ubuntu - https://paste.ubuntu.com/
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =for stopwords Niebur
 
